Learn R Programming

RPesto (version 0.1.4)

fit_cbd: fits the constant-rate birth-death model

Description

fits the constant-rate birth-death model

Usage

fit_cbd(
  phy,
  sampling_fraction,
  tol = 1e-06,
  condition_survival = TRUE,
  condition_root_speciation = TRUE,
  verbose = FALSE
)

Value

a list with the maximum-likelihood parameter estimates of the speciation rate and the extinction rate

Arguments

phy

an object of type phylo

sampling_fraction

the probability that each species was sampled in the tree

tol

the local error threshold in the numerical ODE solver (per delta_t time step)

condition_survival

whether or not to condition on the survival of the left and right lineages descending from the root (default TRUE)

condition_root_speciation

whether or not to condition on that there was a speciation event at the root node (default TRUE)

verbose

whether or not to print more information