fits the constant-rate birth-death model
fit_cbd(
phy,
sampling_fraction,
tol = 1e-06,
condition_survival = TRUE,
condition_root_speciation = TRUE,
verbose = FALSE
)a list with the maximum-likelihood parameter estimates of the speciation rate and the extinction rate
an object of type phylo
the probability that each species was sampled in the tree
the local error threshold in the numerical ODE solver (per delta_t time step)
whether or not to condition on the survival of the left and right lineages descending from the root (default TRUE)
whether or not to condition on that there was a speciation event at the root node (default TRUE)
whether or not to print more information